WsEmitColors

Struct WsEmitColors 

pub struct WsEmitColors<'a> {
    pub set: &'a str,
    pub reset: &'a str,
    pub ws: &'a str,
}
The painted spans produced by ws_check_emit for --ws-error-highlight.

set/reset/ws are the color escapes for the normal line color, the reset, and the whitespace-error highlight. When color is off they are all empty and the output is just the original line bytes.

Fields

set: &'a str

color.diff.new (or the relevant line color) — normal text.

reset: &'a str

The reset escape.

ws: &'a str

color.diff.whitespace — the whitespace-error highlight.