MergeConflictKind

Enum MergeConflictKind 

pub enum MergeConflictKind {
    Content {
        add_add: bool,
    },
    ModifyDelete {
        deleted_in: String,
        modified_in: String,
    },
    RenameContent {
        old_path: Vec<u8>,
    },
    RenameDelete {
        old_path: Vec<u8>,
        renamed_in: String,
        deleted_in: String,
    },
}
The kind of conflict recorded for a path, used to render the stable conflict-type token and human message.

Variants



Content

Both sides changed the file content differently (or both added it with differing content — an add/add).

Fields

add_add: bool


ModifyDelete

The file was deleted on one side and modified on the other.

Fields

deleted_in: String

The side label that deleted the path.

modified_in: String

The side label that modified (and thus kept) the path.



RenameContent

A file renamed on one side, with a content conflict against the other side’s change at the destination.

Fields

old_path: Vec<u8>

The original (pre-rename) path.



RenameDelete

A file renamed on one side whose source was deleted on the other side.

Fields

old_path: Vec<u8>

The pre-rename source path.

renamed_in: String

The side label that performed the rename.

deleted_in: String

The side label that deleted the source.