pub enum MergeConflictKind {
Content {
add_add: bool,
},
ModifyDelete {
deleted_in: String,
modified_in: String,
},
RenameContent {
old_path: Vec<u8>,
},
RenameDelete {
old_path: Vec<u8>,
renamed_in: String,
deleted_in: String,
},
}Expand description
The kind of conflict recorded for a path, used to render the stable conflict-type token and human message.
Variants
Content
Both sides changed the file content differently (or both added it with differing content — an add/add).
ModifyDelete
The file was deleted on one side and modified on the other.
Fields
RenameContent
A file renamed on one side, with a content conflict against the other side’s change at the destination.
RenameDelete
A file renamed on one side whose source was deleted on the other side.