pub fn enable_function_context(context: usize) -> usize
Encode -W / --function-context into the context field without changing the option shape used by the existing renderer call sites.
-W
--function-context