pub struct Hunk {
pub old_start: usize,
pub old_len: usize,
pub new_start: usize,
pub new_len: usize,
pub lines: Vec<HunkLine>,
pub old_no_newline: bool,
pub new_no_newline: bool,
}Expand description
A single @@ -old_start,old_len +new_start,new_len @@ hunk.
old_start / new_start are 1-based line numbers as they appear in the
patch header. The *_no_newline flags record that the final line on that
side of the hunk is not terminated by a newline (the \ No newline at end of file marker).
Fields
old_start: usizeold_len: usizenew_start: usizenew_len: usizelines: Vec<HunkLine>old_no_newline: boolThe last context/deleted line of the old file lacks a trailing newline.
new_no_newline: boolThe last context/inserted line of the new file lacks a trailing newline.